# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`mofed`](#mofed): Manage Mellanox OFED
* [`mofed::opensm`](#mofed--opensm): Manage OpenSM
* [`mofed::srp`](#mofed--srp): Manage SRP

#### Private Classes

* `mofed::config`
* `mofed::install`
* `mofed::repo`
* `mofed::service`

### Defined types

* [`mofed::interface`](#mofed--interface): Manage IPoIB interface

## Classes

### <a name="mofed"></a>`mofed`

Manage Mellanox OFED

#### Examples

##### Basic usage using local yum repo for MOFED

```puppet
class { 'mofed':
  repo_baseurl => 'http://example.com/mlnx/$releasever/3.4-2.0.0.0-rhel7.3/'
  repo_gpgkey  => 'http://example.com/mlnx/$releasever/3.4-2.0.0.0-rhel7.3/RPM-GPG-KEY-Mellanox',
}
```

#### Parameters

The following parameters are available in the `mofed` class:

* [`manage_repo`](#-mofed--manage_repo)
* [`repo_baseurl`](#-mofed--repo_baseurl)
* [`repo_gpgcheck`](#-mofed--repo_gpgcheck)
* [`repo_gpgkey`](#-mofed--repo_gpgkey)
* [`repo_exclude`](#-mofed--repo_exclude)
* [`repo_priority`](#-mofed--repo_priority)
* [`manage_packages`](#-mofed--manage_packages)
* [`package_ensure`](#-mofed--package_ensure)
* [`package_name`](#-mofed--package_name)
* [`extra_packages`](#-mofed--extra_packages)
* [`extra_packages_hiera_merge`](#-mofed--extra_packages_hiera_merge)
* [`manage_service`](#-mofed--manage_service)
* [`restart_service`](#-mofed--restart_service)
* [`openibd_service_name`](#-mofed--openibd_service_name)
* [`openibd_service_ensure`](#-mofed--openibd_service_ensure)
* [`openibd_service_enable`](#-mofed--openibd_service_enable)
* [`openibd_service_hasstatus`](#-mofed--openibd_service_hasstatus)
* [`openibd_service_hasrestart`](#-mofed--openibd_service_hasrestart)
* [`manage_config`](#-mofed--manage_config)
* [`openib_config_path`](#-mofed--openib_config_path)
* [`openib_shellvars`](#-mofed--openib_shellvars)
* [`interfaces`](#-mofed--interfaces)

##### <a name="-mofed--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Boolean to set if MOFED repo should be managed

Default value: `true`

##### <a name="-mofed--repo_baseurl"></a>`repo_baseurl`

Data type: `Optional[String]`

The baseurl of the yumrepo resource

Default value: `undef`

##### <a name="-mofed--repo_gpgcheck"></a>`repo_gpgcheck`

Data type: `Enum['1','0']`

The gpgcheck of the yumrepo resource

Default value: `'1'`

##### <a name="-mofed--repo_gpgkey"></a>`repo_gpgkey`

Data type: `Optional[String]`

The gpgkey of the yumrepo resource

Default value: `undef`

##### <a name="-mofed--repo_exclude"></a>`repo_exclude`

Data type: `Optional[String]`

The exclude of the yumrepo resource

Default value: `undef`

##### <a name="-mofed--repo_priority"></a>`repo_priority`

Data type: `Optional[String]`

The priority of the yumrepo resource

Default value: `undef`

##### <a name="-mofed--manage_packages"></a>`manage_packages`

Data type: `Boolean`

Boolean to determine if packages should be managed

Default value: `true`

##### <a name="-mofed--package_ensure"></a>`package_ensure`

Data type: `String`

The package ensure property

Default value: `'present'`

##### <a name="-mofed--package_name"></a>`package_name`

Data type: `String`

The MOFED package name to install

Default value: `'mlnx-ofed-basic'`

##### <a name="-mofed--extra_packages"></a>`extra_packages`

Data type: `Optional[Array]`

An array of additional packages to install

Default value: `undef`

##### <a name="-mofed--extra_packages_hiera_merge"></a>`extra_packages_hiera_merge`

Data type: `Boolean`

Boolean that sets if extra_packages should have values merged from hiera

Default value: `false`

##### <a name="-mofed--manage_service"></a>`manage_service`

Data type: `Boolean`

Boolean that determines if the openibd service should be managed

Default value: `true`

##### <a name="-mofed--restart_service"></a>`restart_service`

Data type: `Boolean`

Boolean that sets of openibd should be restarted

Default value: `false`

##### <a name="-mofed--openibd_service_name"></a>`openibd_service_name`

Data type: `String`

Name of the openibd service

Default value: `'openibd'`

##### <a name="-mofed--openibd_service_ensure"></a>`openibd_service_ensure`

Data type: `String`

openibd service ensure property

Default value: `'running'`

##### <a name="-mofed--openibd_service_enable"></a>`openibd_service_enable`

Data type: `Boolean`

openibd service enable property

Default value: `true`

##### <a name="-mofed--openibd_service_hasstatus"></a>`openibd_service_hasstatus`

Data type: `Boolean`

openibd service hasstatus property

Default value: `true`

##### <a name="-mofed--openibd_service_hasrestart"></a>`openibd_service_hasrestart`

Data type: `Boolean`

openibd service hasrestart property

Default value: `true`

##### <a name="-mofed--manage_config"></a>`manage_config`

Data type: `Boolean`

Boolean that sets if configs should be managed

Default value: `true`

##### <a name="-mofed--openib_config_path"></a>`openib_config_path`

Data type: `Stdlib::Absolutepath`

Path to openib.conf

Default value: `'/etc/infiniband/openib.conf'`

##### <a name="-mofed--openib_shellvars"></a>`openib_shellvars`

Data type: `Hash`

Hash of shellvar resources

Default value: `{}`

##### <a name="-mofed--interfaces"></a>`interfaces`

Data type: `Hash`

Hash of mofed::interface resources

Default value: `{}`

### <a name="mofed--opensm"></a>`mofed::opensm`

Manage OpenSM

#### Examples

##### Manage OpenSM on two specific ports

```puppet
class { 'mofed::opensm':
  ports => ['mlx4_1 1', 'mlx4_1 2'],
}
```

#### Parameters

The following parameters are available in the `mofed::opensm` class:

* [`ensure`](#-mofed--opensm--ensure)
* [`ports`](#-mofed--opensm--ports)
* [`sweep`](#-mofed--opensm--sweep)

##### <a name="-mofed--opensm--ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'disabled']`

State of opensm.  `present` will run opensm.
`disabled` will install and configure opensm but disable services.
`absent` will remove opensm.

Default value: `'present'`

##### <a name="-mofed--opensm--ports"></a>`ports`

Data type: `Array`

Ports used by opensm

Default value: `[]`

##### <a name="-mofed--opensm--sweep"></a>`sweep`

Data type: `Integer`

Value passsed to opensm `-s` argument.

Default value: `10`

### <a name="mofed--srp"></a>`mofed::srp`

Manage SRP

#### Examples

##### Manage SRP for specific ports

```puppet
class { 'mofed::srp':
 ports => ['mlx4_1 1', 'mlx4_1 2'],
}
```

#### Parameters

The following parameters are available in the `mofed::srp` class:

* [`ensure`](#-mofed--srp--ensure)
* [`ports`](#-mofed--srp--ports)
* [`srp_daemon_config`](#-mofed--srp--srp_daemon_config)
* [`ib_srp_options`](#-mofed--srp--ib_srp_options)

##### <a name="-mofed--srp--ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'disabled']`

State of srp.  `present` will run opensm.
`disabled` will install and configure opensm but disable services.
`absent` will remove opensm.

Default value: `'present'`

##### <a name="-mofed--srp--ports"></a>`ports`

Data type: `Array`

Ports used by srp daemon.

Default value: `[]`

##### <a name="-mofed--srp--srp_daemon_config"></a>`srp_daemon_config`

Data type: `Optional[Variant[String, Array]]`

Define lines in srp_daemon.conf

Default value: `undef`

##### <a name="-mofed--srp--ib_srp_options"></a>`ib_srp_options`

Data type: `Optional[Hash[String, Variant[String,Integer], 1]]`

Options passed to ib_srp kernel module

Default value: `undef`

## Defined types

### <a name="mofed--interface"></a>`mofed::interface`

Manage IPoIB interface

#### Examples

##### Add IPoIB interface

```puppet
mofed::interface { 'ib0':
  ensure         => 'present',
  ipaddr         => '10.0.0.1',
  netmask        => '255.255.0.0',
  connected_mode => 'no',
}
```

#### Parameters

The following parameters are available in the `mofed::interface` defined type:

* [`ipaddr`](#-mofed--interface--ipaddr)
* [`netmask`](#-mofed--interface--netmask)
* [`gateway`](#-mofed--interface--gateway)
* [`ensure`](#-mofed--interface--ensure)
* [`enable`](#-mofed--interface--enable)
* [`nm_controlled`](#-mofed--interface--nm_controlled)
* [`connected_mode`](#-mofed--interface--connected_mode)
* [`mtu`](#-mofed--interface--mtu)
* [`bonding`](#-mofed--interface--bonding)
* [`bonding_slaves`](#-mofed--interface--bonding_slaves)
* [`bonding_opts`](#-mofed--interface--bonding_opts)

##### <a name="-mofed--interface--ipaddr"></a>`ipaddr`

Data type: `Optional[Stdlib::IP::Address]`

IP address, required when ensure=present

Default value: `undef`

##### <a name="-mofed--interface--netmask"></a>`netmask`

Data type: `Optional[Stdlib::IP::Address]`

Netmask address, required when ensure=present

Default value: `undef`

##### <a name="-mofed--interface--gateway"></a>`gateway`

Data type: `Optional[Stdlib::IP::Address]`

Gateway address.

Default value: `undef`

##### <a name="-mofed--interface--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Interface ensure value.

Default value: `'present'`

##### <a name="-mofed--interface--enable"></a>`enable`

Data type: `Boolean`

Boolean of whether to enable the interface at boot.

Default value: `true`

##### <a name="-mofed--interface--nm_controlled"></a>`nm_controlled`

Data type: `Optional[Enum['yes','no']]`

Value for nm_controlled on interface

Default value: `undef`

##### <a name="-mofed--interface--connected_mode"></a>`connected_mode`

Data type: `Enum['yes', 'no']`

The value for setting interface to connected mode.

Default value: `'yes'`

##### <a name="-mofed--interface--mtu"></a>`mtu`

Data type: `Optional[Integer]`

The MTU of the interface.

Default value: `undef`

##### <a name="-mofed--interface--bonding"></a>`bonding`

Data type: `Boolean`

If this interface is a bonding interface

Default value: `false`

##### <a name="-mofed--interface--bonding_slaves"></a>`bonding_slaves`

Data type: `Array[String]`

Array of interfaces that should be enslaved in the bonding interface

Default value: `[]`

##### <a name="-mofed--interface--bonding_opts"></a>`bonding_opts`

Data type: `String`

The bonding options to use for this bonding interface

Default value: `'mode=active-backup miimon=100'`

